Description: The Nevada Judiciary website contains regularly updated information dealing with the Supreme Court of Nevada, Administrative Offices of the Court, among others. Recent decisions, judiciary news, schedules, oral argument calendars, statistics, court sponsored committees and programs and publications can be viewed on this site.
Keywords: nevada, supreme, court, courts, washoe county, clerk, courtroom, phrases, municipal, law library, district, justice, administrative, judiciary, rules, civil, procedure, expressions, federal, justice, family, cases, case, report, branch, judicial, opinions, argument, settlement, judges, bar, exam, washoe, county

Mindful Images Photography

# Unpublished Orders

Case Number | Case Title | Date
--- | --- | ---
67904 | MORALES VS. STATE, DEP'T OF CORRECTIONS | Jul 28, 2015
68360 | GRECO VS. UNINCORPORATED TOWN OF PAHRUMP | Jul 28, 2015
68394 | RAMSEY VS. DIST. CT. (THE CITY OF N. LAS VEGAS) | Jul 27, 2015
68399 | RUIZ VS. STATE, DEP'T OF CORRECTIONS | Jul 27, 2015
68306 | JONES VS. ROBERTS | Jul 27, 2015
68133 | JACKSON (RAYMOND) VS. STATE | Jul 27, 2015
68217 | KOLENDER VS. KOLENDER (CHILD CUSTODY) | Jul 27, 2015
68225 | VARNER (JACOB) VS. STATE | Jul 27, 2015
68355 | MATTHEWS, JR. VS. LAS VEGAS JUSTICE CT. CLERK DEP'T. 7 | Jul 27, 2015
67898 | FREEDOM MORTG. CORP. VS. ZAISAN ENTER. LLC | Jul 27, 2015
67748 | TALBO VS. STATE, DEP'T OF FAMILY SERV. | Jul 27, 2015
67360 | ROBINSON VS. KAROSA | Jul 27, 2015
64475 | SISCO VS. DIST. CT. (SHARP) | Jul 27, 2015
64917 | MARTINEZ VS. DAVYN HOMEOWNERS' ASS'N. | Jul 24, 2015
65606 | KENNEDY (JOSEPH) VS. STATE | Jul 24, 2015
65715 | JB CARTER PROP. II, LLC VS. GASHTILI | Jul 24, 2015
66427 | BRADY VS. MILLER | Jul 24, 2015
66633 | BERQUIST VS. DIST. CT. (BERQUIST) | Jul 24, 2015
67181 | FISHER (DONALD) VS. STATE | Jul 24, 2015
68005 | ESPINOZA (DREW) VS. CITY OF HENDERSON | Jul 24, 2015
68131 | VILLAS AT FLAMINGO HOMEOWNERS ASS'N, INC. VS. DIST. CT. (MONTE CARLO INV'S., LLC) | Jul 24, 2015
68127 | VALLEY HEALTH SYS., LLC VS. DIST. CT. (WATERS-MARIA) | Jul 23, 2015
68181 | IN RE: PARENTELLA DE CRUZ TRUST | Jul 23, 2015
68311 | PARK WEST COMPANIES, INC. VS. DIST. CT. (AMAZON CONSTR. CORP.) | Jul 23, 2015
68215 | WILLING VS. DIST. CT. (NYE CNTY. DIST. ATTY.) | Jul 23, 2015
68270 | AERO LIQUIDATION, INC. VS. DIST. CT. (CLOUD INV. PARTNERS, LLLP) | Jul 23, 2015
68276 | ELSINORE III, LLC VS. DIST. CT. (POSHBABY, LLC) | Jul 23, 2015
67098 | RUSSELL VS. PAPPAS | Jul 23, 2015
67214 | DANCER VS. DANCER (CHILD CUSTODY) | Jul 23, 2015
67229 | BUSSE VS. BUSSE (CHILD CUSTODY) | Jul 23, 2015
67364 | FRANKLIN VS. LAUGHLIN | Jul 23, 2015
67457 | WHITEHEAD VS. COX | Jul 23, 2015
67629 | ALI VS. ARIF | Jul 23, 2015
67728 | IN RE: J.O., MINOR CHILD | Jul 23, 2015
67651 | BURDSAL VS. THE SIXTH JUD. DIST. CT. | Jul 23, 2015
67661 | WARENBACK VS. STATE | Jul 23, 2015
67879 | MCCURDY VS. WILLIAMS | Jul 23, 2015
66140 | KOZLOWSKI VS. DOUGLAS CNTY. | Jul 23, 2015
66710 | MORROW VS. BISBEE | Jul 23, 2015
66736 | O'NEAL VS. THE SECOND JUD. DIST. CT. | Jul 23, 2015
66905 | REED, II VS. THE SEVENTH JUDICIAL DIST. CT. | Jul 23, 2015
66991 | WARENBACK VS. STATE OF NEV. | Jul 23, 2015
67003 | HELFRICH VS. THE FIFTH JUD. DIST. CT. | Jul 23, 2015
67093 | RASKE VS. THE EIGHTH JUD. DIST. CT. | Jul 23, 2015

#### Appellate Courts Decisions

- Advance Opinions
- Forthcoming Opinions
- Nevada Reports
- Supreme Court Unpublished Orders
- Court of Appeals Unpublished Orders

Privacy Policy | Site Map | Back to Top ↑